from setuptools import setup

setup(
    name='BaiduFace',
    version='1.2',
    package_dir={'bdface': 'src'},
    packages=['bdface'],
    author='wcy',
    author_email='1208640961@qq.com',
    description='Call baidu face recognition recommendation system'
)
